==> xlnl-3.4.9.tar.gz: xlnl-3.4.9/src/gfile-ver.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: gfile-ver.h,v 1.59 2009/07/11 14:22:20 bowkenken Exp $
***************************************************************/

#ifndef	GFILE_VER_H
#define	GFILE_VER_H

/***************************************************************
* եΥС
***************************************************************/

#define	STR_GAME_RC_HEAD	"# L&L - run command file version "
#define	STR_GAME_CONF_HEAD	"# L&L - configure file version "
#define	STR_GAME_DATA_HEAD	"# L&L - data file version "
#define	STR_GAME_REPLAY_HEAD	"# L&L - replay file version "
#define	STR_GRAPH_CONF_HEAD	"# L&L - graphic configure - version "


/***************************************************************
* ե ~/.lnl/usr/lnl.conf
* History:
* 1.0.0
* 1.0.1
* 1.0.2
* 1.0.3
*   2004/??/??
*   ե̾ lnl_conf  lnl.conf ѹ
* 1.0.4
*   2004/12/23
*   西褹¸ͤˤ
* 1.0.5
*   2004/12/30
*   ХåեΥꥢ¸ͤˤ
* 1.0.6
*   2005/01/04
*   ɽ˥塼ꤷ¸ͤˤ
* 1.0.7
*   2008/04/04
*   ̥򥻡֤ͤˤ
* 1.0.8
*   2008/05/17
*   ˥塼̤ιܤοɲä
* 1.0.9
*   2008/08/15
*   쥦ɥɲ
* 1.0.10
*   2008/09/11
*   饯ȡɥɲ
* 1.0.11
*   2008/09/26
*   祤ƥåɲ
* 1.0.12
*   2009/01/19
*   пڤοɲ
*   2008/09/11
* 1.0.13
*   2009/02/14
*   롦ǥɥɲ
* 1.0.14
*   2009/05/12
*   ɥɸɲ
* 1.0.15
*   2009/05/24
*   åꥹȤΥХåեСԶб
* 1.0.16
*   2009/07/11
*   ˥塼ΥǥեȤؤΥμưưɲ
***************************************************************/

#define	GAME_CONF_VER_MJR	1
#define	GAME_CONF_VER_MNR	0
#define	GAME_CONF_VER_PAT	16


/***************************************************************
* 饯ǡ
* ~/.lnl/save/bin/save??.bin
* ~/.lnl/save/txt/save??.txt
* ~/.lnl/save/cnf/conf??.txt
* History:
* 1.0.0
* 1.0.1
*   2004/??/??
*   ˥塼ɲá
*   ưޡΥƥɲá
* 1.0.2
*   2004/??/??
*   ʸμֹ(enum spell_kind_t)
*   ѹƤбͤˤ
* 1.0.3
*   2004/??/??
*   ƥࡢ󥹥櫡եȡ
*   μֹ(enum *_kind_t)
*   ѹƤбͤˤ
* 1.0.4
*   2004/12/??
*   ưޡ˥塼ɲä
* 1.0.5
*   2005/01/02
*   ƥιɲ
* 1.0.6
*   2005/01/12
*   ƥ༱̡פμʸȴʪɲ
* 1.0.7
*   2005/01/13
*   ֥̥㥯פɲ
* 1.0.8
*   2005/07/31
*   쥢ƥϤʤۤפɲ
* 1.1.0
*   2005/09/02
*   ưޡ̥ե˰ư
* 1.1.1
*   2005/09/07
*   ưޡ˥ޥͤˤ
* 1.1.2
*   2006/02/17
*   פμʸɲ
* 1.1.3
*   2005/09/07
*   ˥塼Υȥܺ٤ȥҥȤʬ
* 1.1.4
*   2006/08/20
*   饯ΥǡȴŶ᤿
* 1.1.5
*   2006/08/21
*   ֤ƥɤȰ NPC 
*   ̤ʤʤΤ
* 1.1.6
*   2006/09/17
*   FX_KIND_COUNTER_MAGIC ɲ
* 1.1.7
*   2006/09/19
*   FX_KIND_POLYMORPH ɲ
* 1.1.8
*   2007/03/18
*   µܤθߤγؿ򥻡ֽͤˤ
* 1.1.9
*   2007/03/20
*   ˥塼κϿ 50 åȤˤ
* 1.2.0
*   2007/03/22
*   lnl.conf ѻߤ conf??.txt եܹ
*    lnl.conf ϽѤȤƻĤ
* 1.2.1
*   2007/03/23
*   ץ쥤ǽ
* 1.2.2
*   2007/03/30
*   μ򥻡֤ͤˤ
* 1.2.3
*   2007/05/14
*   ƥμ̺Ѥߥե饰򥻡֤ͤˤ
* 1.2.4
*   2008/04/03
*   ̥򥻡֤ͤˤ
* 1.2.5
*   2008/04/12
*   ξˡּ̺ѡפȡ̡̤פɲ
* 1.2.6
*   2008/05/10
*   ǽŤͤȸʤʤԶб
* 1.2.7
*   2008/05/13
*   Υե̾򥻡֤ͤˤ
* 1.2.8
*   2008/05/17
*   ˥塼̤ιܤοɲä
* 1.2.9
*   2008/05/19
*   ƥˡΥפɲ
* 1.2.10
*   2008/08/11
*   ˾ߡפεɲ
* 1.2.11
*   2008/08/15
*   쥦ɥɲ
* 1.2.12
*   2008/09/02
*   κϥ֤ʤͤˤ
* 1.2.13
*   2008/09/11
*   饯ȡɥɲ
* 1.2.14
*   2008/09/26
*   祤ƥåɲ
* 1.2.15
*   2008/12/28
*   ƥɲ
* 1.2.16
*   2009/01/05
*   ֤Υפɲ
* 1.2.17
*   2009/01/06
*   ࡦƥեȤɲ
* 1.2.18
*   2009/01/19
*   пڤοɲ
* 1.2.19
*   2009/02/03
*   ɲ
* 1.2.20
*   2009/05/12
*   ɥɸɲ
* 1.2.21
*   2009/05/20
*   16 ʿΥǡ "0x" ץեåĤƤʤäΤ
* 1.2.22
*   2009/05/24
*   åꥹȤΥХåեСԶб
* 1.2.23
*   2009/05/27
*   󥫡Υǡɲ
* 1.2.24
*   2009/07/11
*   ˥塼ΥǥեȤؤΥμưưɲ
***************************************************************/

#define	GAME_DATA_VER_MJR	1
#define	GAME_DATA_VER_MNR	2
#define	GAME_DATA_VER_PAT	24


/***************************************************************
* եå
* ~/.lnl/xlnl/graph/???/xlnl-conf.txt
* History:
* 1.0.0
***************************************************************/

#define	GRAPH_CONF_VER_MJR	1
#define	GRAPH_CONF_VER_MNR	0
#define	GRAPH_CONF_VER_PAT	0


#endif	/* GFILE_VER_H */

==> xlnl-3.4.19.tar.gz: xlnl-3.4.19/src/gfile-ver.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: gfile-ver.h,v 1.79 2011/01/09 01:58:25 bowkenken Exp $
***************************************************************/

#ifndef	GFILE_VER_H
#define	GFILE_VER_H

/***************************************************************
* եΥС
***************************************************************/

#define	STR_GAME_RC_HEAD	"# L&L - run command file version "
#define	STR_GAME_CONF_HEAD	"# L&L - configure file version "
#define	STR_GAME_DATA_HEAD	"# L&L - data file version "
#define	STR_GAME_REPLAY_HEAD	"# L&L - replay file version "
#define	STR_GRAPH_CONF_HEAD	"# L&L - graphic configure - version "


/***************************************************************
* ե ~/.lnl/usr/lnl.conf
* History:
* 1.0.0
* 1.0.1
* 1.0.2
* 1.0.3
*   2004/??/??
*   ե̾ lnl_conf  lnl.conf ѹ
* 1.0.4
*   2004/12/23
*   西褹¸ͤˤ
* 1.0.5
*   2004/12/30
*   ХåեΥꥢ¸ͤˤ
* 1.0.6
*   2005/01/04
*   ɽ˥塼ꤷ¸ͤˤ
* 1.0.7
*   2008/04/04
*   ̥򥻡֤ͤˤ
* 1.0.8
*   2008/05/17
*   ˥塼̤ιܤοɲä
* 1.0.9
*   2008/08/15
*   쥦ɥɲ
* 1.0.10
*   2008/09/11
*   饯ȡɥɲ
* 1.0.11
*   2008/09/26
*   祤ƥåɲ
* 1.0.12
*   2009/01/19
*   пڤοɲ
*   2008/09/11
* 1.0.13
*   2009/02/14
*   롦ǥɥɲ
* 1.0.14
*   2009/05/12
*   ɥɸɲ
* 1.0.15
*   2009/05/24
*   åꥹȤΥХåեСԶб
* 1.0.16
*   2009/07/11
*   ˥塼ΥǥեȤؤΥμưưɲ
* 1.0.17
*   2009/08/09
*   ޥåײ̤ΥĴɲ
* 1.0.18
*   2009/08/21
*   ե󥯥󡦥󥹤ɲ
* 1.0.19
*   2009/10/04
*   BGM/SE β̤ɲ
* 1.0.20
*   2010/02/24
*   Хåեɲ
* 1.0.21
*   2010/07/19
*   CUI ޥΥ֥롦åֳ֤ɲ
* 1.0.22
*   2010/07/21
*   Υѥֹɲ
* 1.0.23
*   2010/07/22
*   ơСΥҥɽɲ
* 1.0.24
*   2010/07/22
*   ٤
***************************************************************/

#define	GAME_CONF_VER_MJR	1
#define	GAME_CONF_VER_MNR	0
#define	GAME_CONF_VER_PAT	24


/***************************************************************
* 饯ǡ
* ~/.lnl/save/bin/save??.bin
* ~/.lnl/save/txt/save??.txt
* ~/.lnl/save/cnf/conf??.txt
* History:
* 1.0.0
* 1.0.1
*   2004/??/??
*   ˥塼ɲá
*   ưޡΥƥɲá
* 1.0.2
*   2004/??/??
*   ʸμֹ(enum spell_kind_t)
*   ѹƤбͤˤ
* 1.0.3
*   2004/??/??
*   ƥࡢ󥹥櫡եȡ
*   μֹ(enum *_kind_t)
*   ѹƤбͤˤ
* 1.0.4
*   2004/12/??
*   ưޡ˥塼ɲä
* 1.0.5
*   2005/01/02
*   ƥιɲ
* 1.0.6
*   2005/01/12
*   ƥ༱̡פμʸȴʪɲ
* 1.0.7
*   2005/01/13
*   ֥̥㥯פɲ
* 1.0.8
*   2005/07/31
*   쥢ƥϤʤۤפɲ
* 1.1.0
*   2005/09/02
*   ưޡ̥ե˰ư
* 1.1.1
*   2005/09/07
*   ưޡ˥ޥͤˤ
* 1.1.2
*   2006/02/17
*   פμʸɲ
* 1.1.3
*   2005/09/07
*   ˥塼Υȥܺ٤ȥҥȤʬ
* 1.1.4
*   2006/08/20
*   饯ΥǡȴŶ᤿
* 1.1.5
*   2006/08/21
*   ֤ƥɤȰ NPC 
*   ̤ʤʤΤ
* 1.1.6
*   2006/09/17
*   FX_KIND_COUNTER_MAGIC ɲ
* 1.1.7
*   2006/09/19
*   FX_KIND_POLYMORPH ɲ
* 1.1.8
*   2007/03/18
*   µܤθߤγؿ򥻡ֽͤˤ
* 1.1.9
*   2007/03/20
*   ˥塼κϿ 50 åȤˤ
* 1.2.0
*   2007/03/22
*   lnl.conf ѻߤ conf??.txt եܹ
*    lnl.conf ϽѤȤƻĤ
* 1.2.1
*   2007/03/23
*   ץ쥤ǽ
* 1.2.2
*   2007/03/30
*   μ򥻡֤ͤˤ
* 1.2.3
*   2007/05/14
*   ƥμ̺Ѥߥե饰򥻡֤ͤˤ
* 1.2.4
*   2008/04/03
*   ̥򥻡֤ͤˤ
* 1.2.5
*   2008/04/12
*   ξˡּ̺ѡפȡ̡̤פɲ
* 1.2.6
*   2008/05/10
*   ǽŤͤȸʤʤԶб
* 1.2.7
*   2008/05/13
*   Υե̾򥻡֤ͤˤ
* 1.2.8
*   2008/05/17
*   ˥塼̤ιܤοɲä
* 1.2.9
*   2008/05/19
*   ƥˡΥפɲ
* 1.2.10
*   2008/08/11
*   ˾ߡפεɲ
* 1.2.11
*   2008/08/15
*   쥦ɥɲ
* 1.2.12
*   2008/09/02
*   κϥ֤ʤͤˤ
* 1.2.13
*   2008/09/11
*   饯ȡɥɲ
* 1.2.14
*   2008/09/26
*   祤ƥåɲ
* 1.2.15
*   2008/12/28
*   ƥɲ
* 1.2.16
*   2009/01/05
*   ֤Υפɲ
* 1.2.17
*   2009/01/06
*   ࡦƥեȤɲ
* 1.2.18
*   2009/01/19
*   пڤοɲ
* 1.2.19
*   2009/02/03
*   ɲ
* 1.2.20
*   2009/05/12
*   ɥɸɲ
* 1.2.21
*   2009/05/20
*   16 ʿΥǡ "0x" ץեåĤƤʤäΤ
* 1.2.22
*   2009/05/24
*   åꥹȤΥХåեСԶб
* 1.2.23
*   2009/05/27
*   󥫡Υǡɲ
* 1.2.24
*   2009/07/11
*   ˥塼ΥǥեȤؤΥμưưɲ
* 1.2.25
*   2009/07/24
*   ƥ̾ɲ
* 1.2.26
*   2009/07/30
*   ԡפμʸɲ
* 1.2.27
*   2009/08/09
*   ¾ѿȡפǥ饯ǡʤäΤ
* 1.2.28
*   2009/08/09
*   ޥåײ̤ΥĴɲ
* 1.2.29
*   2009/08/21
*   ե󥯥󡦥󥹤ɲ
* 1.2.30
*   2009/09/18
*   ֥֡δʪפɲ
* 1.2.31
*   2009/10/04
*   BGM/SE β̤ɲ
* 1.2.32
*   2010/02/24
*   Хåեɲ
* 1.2.33
*   2010/05/17
*   ǥեȤκɲ
* 1.2.34
*   2010/05/19
*   ûΥžܡפμʸɲ
* 1.2.35
*   2010/05/29
*   ǥեȤκŤ֡ǡ˼ưɲäͤˤ
* 1.2.36
*   2010/06/24
*   ǥեȰʳκС֤ڤ괹ͤˤ
* 1.2.37
*   2010/07/19
*   CUI ޥΥ֥롦åֳ֤ɲ
* 1.2.38
*   2010/07/21
*   Υѥֹɲ
* 1.2.39
*   2010/07/22
*   ơСΥҥɽɲ
* 1.2.40
*   2010/07/22
*   ٤
* 1.2.41
*   2010/08/05
*   פɲ
***************************************************************/

#define	GAME_DATA_VER_MJR	1
#define	GAME_DATA_VER_MNR	2
#define	GAME_DATA_VER_PAT	41


/***************************************************************
* եå
* ~/.lnl/xlnl/graph/???/xlnl-conf.txt
* History:
* 1.0.0
***************************************************************/

#define	GRAPH_CONF_VER_MJR	1
#define	GRAPH_CONF_VER_MNR	0
#define	GRAPH_CONF_VER_PAT	0


#endif	/* GFILE_VER_H */
